@@ -12,7 +12,7 @@
 #' profile <- GeoTcgaData::profile
 #' result <- id_conversion(profile)
 #' }
-id_conversion<-function(profiles, toType = "SYMBOL"){  
+id_conversion <- function(profiles, toType = "SYMBOL"){  
     # rownames(profiles) <- unlist(lapply(rownames(profiles), function(x) unlist(strsplit(x,"\\."))[1]))
     # file3 <- hgnc
     # rownames(file3)<-file3[,5]
@@ -22,10 +22,11 @@ id_conversion<-function(profiles, toType = "SYMBOL"){
     # rownames(profiles_new) <- mat[,1]
     # profiles_new
     ## use clusterProfiler::bitr to convert gene id
-    rownames(profiles) <- unlist(lapply(rownames(profiles), function(x) unlist(strsplit(x,"\\."))[1]))
+    # rownames(profiles) <- unlist(lapply(rownames(profiles), function(x) unlist(strsplit(x,"\\."))[1]))
+    rownames(profiles) <- gsub("\\..*", "", rownames(profiles))
     genes <- clusterProfiler::bitr(rownames(profiles), fromType = "ENSEMBL", 
         toType = toType, OrgDb = org.Hs.eg.db::org.Hs.eg.db, drop = FALSE)[, 2]
-    profiles_new <- profiles[!is.na(genes), ]
+    profiles_new <- as.matrix(profiles[!is.na(genes), ])
     rownames(profiles_new) <- genes[!is.na(genes)]
     profiles_new
 }
